Name:       thermostat
Version:    0.4.0
Release:    3%{?dist}
Summary:    A monitoring and serviceability tool for OpenJDK
License:    GPLv2+ with exceptions
URL:        http://icedtea.classpath.org/thermostat/
# Should we use something like this for rawhide? I.e. push
# a build every so often based on a HG revision
#Source0:    http://icedtea.classpath.org/hg/thermostat/archive/0.3.tar.bz2
Source0:    http://icedtea.classpath.org/download/%{name}/%{name}-%{version}.tar.gz
Patch0:     per-user-home.patch
# Don't build web stuff and remove jacoco references
Patch1:     fix_pom.patch
# This should be a F17 only patch. F18 and up has lucene 3.6
Patch2:     lucene_2.9.4_compat.patch
# Use System.load() over System.loadLibrary() as per Java packaging guidelines
Patch3:     fix_natives.patch
# Start all deps as bundles
Patch4:     fix_bundle_loading.patch
# Honor user provided CFLAGS and LDFLAGS
Patch5:     fix_natives_buildflags.patch

BuildRequires:  java-devel >= 1:1.7.0
BuildRequires:  jpackage-utils

BuildRequires: maven
BuildRequires: maven-dependency-plugin
BuildRequires: maven-surefire-plugin
BuildRequires: maven-surefire-provider-junit4
# Native bits are built with this
BuildRequires: maven-plugin-exec

BuildRequires: libgnome-keyring-devel
BuildRequires: felix-framework
BuildRequires: felix-osgi-core
BuildRequires: felix-osgi-compendium
BuildRequires: fusesource-pom
BuildRequires: jansi
# 1.0.14-3 has OSGi metadata
BuildRequires: jfreechart >= 1.0.14-3
# 1.0.17-4 has OSGi metadata
BuildRequires: jcommon >= 1.0.17-4
BuildRequires: apache-commons-logging
BuildRequires: apache-commons-beanutils
BuildRequires: apache-commons-cli
BuildRequires: jline2
BuildRequires: mongo-java-driver
BuildRequires: mongo-java-driver-bson
BuildRequires: netty
BuildRequires: lucene >= 2.9.4
# thermostat-client-core wants itext
BuildRequires: itext-core

Requires: java >= 1:1.7.0
Requires: jpackage-utils

Requires: felix-framework
Requires: felix-osgi-core
Requires: felix-osgi-compendium
Requires: jansi
Requires: java-devel >= 1:1.7.0
Requires: jline2
# 1.0.14-3 has OSGi metadata
Requires: jfreechart >= 1.0.14-3
# 1.0.17-4 has OSGi metadata
Requires: jcommon >= 1.0.17-4
Requires: mongodb
Requires: mongodb-server
Requires: mongo-java-driver
Requires: mongo-java-driver-bson
Requires: netty
Requires: lucene >= 2.9.4
Requires: itext-core
Requires: libgnome-keyring
Requires: apache-commons-logging
Requires: apache-commons-beanutils
Requires: apache-commons-cli

%description
Thermostat is a monitoring and instrumentation tool for the Hotspot JVM,
with support for monitoring multiple JVM instances. The system is made
up of two processes: an Agent, which collects data, and a Client which
allows users to visualize this data. These components communicate via
a MongoDB-based storage layer. A pluggable agent framework allows for
collection of performance data beyond that which is included out of the
box. Support for corresponding pluggable GUI components for visualization
of additional data is pending.

%package javadoc
Summary:    Javadocs for %{name}
Group:      Documentation
Requires:   jpackage-utils

%description javadoc
This package contains the API documentation for %{name}

%prep
%setup -q
%patch0 -p1
%patch1
%patch2 -p1
%patch3 -p1
%patch4 -p1
%patch5 -p1

%build
export CFLAGS="$RPM_OPT_FLAGS" LDFLAGS="$RPM_LD_FLAGS"
mvn-rpmbuild \
     -Dmaven.test.skip=true \
     -Dthermostat.home=%{_datarootdir}/%{name} \
     install javadoc:aggregate

# the build puts all depdency jars into distribution/target/lib as well
mv distribution/target/libs/thermostat-*jar .
rm -f distribution/target/libs/*jar
mv thermostat-*jar distribution/target/libs/

# fix path to java in scripts
sed -i 's|^JAVA=.*|JAVA="/usr/lib/jvm/java-openjdk/jre/bin/java"|' distribution/target/bin/thermostat
sed -i 's|^JAVA=.*|JAVA="/usr/lib/jvm/java-openjdk/jre/bin/java"|' distribution/target/bin/thermostat-client-gui

# remove dirs/files which we don't need shipped
rm -rf distribution/target/maven-archiver
rm -rf distribution/target/thermostat-distribution-0.3.jar
rm -rf distribution/target/osgi-cache

%install
mkdir -p %{buildroot}%{_bindir}
mkdir -p %{buildroot}%{_sysconfdir}/%{name}
mkdir -p %{buildroot}%{_datarootdir}
# JNI things live there
mkdir -p %{buildroot}%{_libdir}/%{name}
mkdir -p %{buildroot}%{_jnidir}

pushd distribution/target/libs
# JNI files are in %{_libdir}
mv thermostat-keyring-%{version}.jar \
   thermostat-agent-core-%{version}.jar \
   %{buildroot}%{_libdir}/%{name}
# Make native libs executable so that debuginfos get properly
# generated
chmod +x native/*.so
mv native/* %{buildroot}%{_libdir}/%{name}
# JNI jars need to be in %{_jnidir}, we symlink to
# %{_libdir}/%{name} files
for i in thermostat-keyring-%{version}.jar \
    thermostat-agent-core-%{version}.jar; do
  ln -s %{_libdir}/%{name}/$i %{buildroot}%{_jnidir}/$i
done
popd

# move everything else into /usr/share/thermostat
cp -a distribution/target %{buildroot}%{_datarootdir}/%{name}

# symlink dependencies into the right directory
build-jar-repository -s -p %{buildroot}%{_datarootdir}/%{name}/libs \
    felix/org.apache.felix.framework \
    felix/org.osgi.core \
    felix/org.osgi.compendium \
    apache-commons-cli \
    apache-commons-collections \
    apache-commons-beanutils \
    apache-commons-logging \
    hawtjni-runtime \
    jansi \
    jcommon \
    jline2 \
    lucene \
    netty \
    mongo
# jfreechart is in it's own subdir in /usr/share/java,
# so do the symlink manually since we want a "jfreechart.jar" symlink
# not "jfreechart_jfreechart.jar" name
ln -s %{_javadir}/jfreechart/jfreechart.jar %{buildroot}%{_datarootdir}/%{name}/libs/jfreechart.jar  

pushd %{buildroot}%{_libdir}/%{name}
# symlink JNI jars
for i in *.jar; do
  ln -s %{_libdir}/%{name}/$i \
        %{buildroot}%{_datarootdir}/%{name}/libs/$i
done
# symlink shared libs
for i in *.so; do
  ln -s %{_libdir}/%{name}/$i \
        %{buildroot}%{_datarootdir}/%{name}/libs/native/$i
done
popd

ln -s /usr/lib/jvm/java-openjdk/lib/tools.jar \
    %{buildroot}%{_datarootdir}/%{name}/libs/

# binary names
ln -s %{_datarootdir}/%{name}/bin/thermostat-client-gui \
    %{buildroot}%{_bindir}/thermostat-client
ln -s %{_datarootdir}/%{name}/bin/thermostat \
    %{buildroot}%{_bindir}/thermostat

# move config files to /etc/ and symlink stuff under /usr/share/thermostat to it

mv %{buildroot}%{_datarootdir}/%{name}/etc/logging.properties \
    %{buildroot}%{_sysconfdir}/%{name}/
ln -s %{_sysconfdir}/%{name}/logging.properties \
    %{buildroot}%{_datarootdir}/%{name}/etc/logging.properties

mv %{buildroot}%{_datarootdir}/%{name}/agent/agent.properties \
    %{buildroot}%{_sysconfdir}/%{name}/agent.properties
ln -s %{_sysconfdir}/%{name}/agent.properties \
    %{buildroot}%{_datarootdir}/%{name}/agent/agent.properties

mv %{buildroot}%{_datarootdir}/%{name}/backends/system/backend.properties \
    %{buildroot}%{_sysconfdir}/%{name}/system-backend.properties
ln -s %{_sysconfdir}/%{name}/system-backend.properties \
    %{buildroot}%{_datarootdir}/%{name}/backends/system/backend.properties

# java docs
mkdir -p %{buildroot}%{_javadocdir}/%{name}
cp -a target/site/apidocs %{buildroot}%{_javadocdir}/%{name}

%files
%doc COPYING
%doc LICENSE
%doc README
%config(noreplace) %{_sysconfdir}/%{name}
%{_datarootdir}/%{name}
%{_libdir}/%{name}
%{_jnidir}
%{_bindir}/thermostat-client
%{_bindir}/thermostat

%files javadoc
%{_javadocdir}/%{name}

%changelog
* Mon Oct 22 2012 Severin Gehwolf <sgehwolf@redhat.com> 0.4.0-3
- Fix RHBZ#868486
- Debug-infos were not properly generated.
- Do not override CFLAGS/LDFLAGS.

* Fri Oct 19 2012 Severin Gehwolf <sgehwolf@redhat.com> 0.4.0-2
- Fix jfreechart.jar symlink name.

* Tue Oct 16 2012 Severin Gehwolf <sgehwolf@redhat.com> 0.4.0-1
- Update to upstream 0.4 release.
- Starts dependencies as bundles.

* Sat Jul 21 2012 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 0.3-3
- Rebuilt for https://fedoraproject.org/wiki/Fedora_18_Mass_Rebuild

* Thu Jul 19 2012 Severin Gehwolf <sgehwolf@redhat.com> 0.3-2
- Removed now obsolete patch (with jfreechart updated to 1.0.14)
- Added BR

* Thu Jul 12 2012 Omair Majid <omajid@redhat.com> - 0.3-1
- Update to upstream 0.3 release

* Sun May 06 2012 Omair Majid <omajid@redhat.com> - 0.2-0.20120506hg2140a7c81a4b
- Resolve RH813539
- Remove uneeded require on fusesource-pom
- Fix jar to use jline2 instead of jline

* Fri May 04 2012 Omair Majid <omajid@redhat.com> - 0.2-0.20120503hg2140a7c81a4b
- Update to pre-release upstream snapshot

* Mon Feb 13 2012 Omair Majid <omajid@redhat.com> - 0.1-1
- Updated description

* Tue Feb 07 2012 Omair Majid <omajid@redhat.com> - 0.1-1
- Intial package
